@@ -5,6 +5,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 from decentra_network.blockchain.block.block_main import Block
+from decentra_network.blockchain.block.save_block import SaveBlock
 from decentra_network.blockchain.candidate_block.candidate_block_main import \
     candidate_block
 from decentra_network.consensus.rounds.round_1.checks.checks_main import \
@@ -15,6 +16,7 @@ from decentra_network.lib.log import get_logger
 from decentra_network.node.get_candidate_blocks import GetCandidateBlocks
 from decentra_network.node.server.server import server
 from decentra_network.node.unl import Unl
+from decentra_network.transactions.pending_to_validating import PendingtoValidating
 
 logger = get_logger("CONSENSUS_FIRST_ROUND")
 
@@ -29,6 +31,8 @@ def consensus_round_1(
     custom_TEMP_BLOCK_PATH: str = None,
     custom_TEMP_BLOCKSHASH_PATH: str = None,
     custom_TEMP_BLOCKSHASH_PART_PATH: str = None,
+    custom_shares=None,
+    custom_fee_address=None,
 ) -> bool:
     """
     At this stage of the consensus process,
@@ -40,17 +44,27 @@ def consensus_round_1(
       round 1 to be done
     """
 
-    logger.debug(
-        f"BLOCK#{block.sequance_number}:{block.empty_block_number} First round is starting"
+    logger.info(
+        f"BLOCK#{block.sequence_number}:{block.empty_block_number} First round is starting"
     )
 
     unl_nodes = (Unl.get_unl_nodes(custom_UNL_NODES_PATH=custom_UNL_NODES_PATH)
                  if custom_unl_nodes is None else custom_unl_nodes)
+    logger.debug(f"unl_nodes: {unl_nodes}")
     candidate_class = (
-        GetCandidateBlocks(custom_nodes_list=Unl.get_as_node_type(unl_nodes))
+        GetCandidateBlocks(custom_nodes_list=Unl.get_as_node_type(unl_nodes), block=block)
         if custom_candidate_class is None else custom_candidate_class)
+    logger.debug(f"candidate_class: {candidate_class.__dict__}")
 
-    if round_check(block, candidate_class, unl_nodes):
+    if round_check(
+        block, 
+        candidate_class, 
+        unl_nodes,
+        custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+        custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
+        custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
+        custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,        
+        ):
         round_process(
             block,
             candidate_class,
@@ -59,10 +73,12 @@ def consensus_round_1(
             custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
             custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
             custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
+            custom_shares=custom_shares,
+            custom_fee_address=custom_fee_address,
         )
+        logger.info("Round 1 check is True")
         return True
     else:
-        custom_server.send_my_block(
-            block
-        ) if custom_server is not None else server.Server.send_my_block(block)
+       
+        logger.warning("Round 1 check is False")
         return False
