@@ -13,6 +13,7 @@ from decentra_network.blockchain.block.create_block import CreateBlock
 from decentra_network.blockchain.block.save_block import SaveBlock
 from decentra_network.consensus.consensus_main import consensus_trigger
 from decentra_network.lib.perpetualtimer import perpetualTimer
+from decentra_network.lib.qr import qr
 from decentra_network.lib.settings_system import the_settings
 from decentra_network.lib.status import Status
 from decentra_network.node.server.server import server
@@ -104,7 +105,18 @@ class NodeBox(MDGridLayout):
 
     # End
 
+    def check_node_server(self):
+        if server.Server is None:
+            SweetAlert().fire(
+                "Please start the node server",
+                type="failure",
+            )
+            return False
+        return True
+
     def stop_node_server(self):
+        if not self.check_node_server():
+            return False
         server.Server.stop()
 
     def connect_to_know_node(self):
@@ -153,9 +165,8 @@ class NodeBox(MDGridLayout):
         ip = text_list[1]
         port = text_list[0]
 
-        print(ip)
-        print(port)
-
+        if not self.check_node_server():
+            return False
         server.Server.connect(ip, int(port))
 
         self.connect_a_node_dialog.dismiss()
@@ -229,6 +240,8 @@ class NodeBox(MDGridLayout):
         self.show_add_unl_node_dialog()
 
     def get_block(self):
+        if not self.check_node_server():
+            return False
         if the_settings()["test_mode"]:
             the_block = CreateBlock()
             SaveBlock(the_block)
@@ -244,6 +257,12 @@ class NodeBox(MDGridLayout):
             type="success",
         )
 
+    def nd_id_qr(self):
+        location_of_qr = qr(server.id)
+        SweetAlert().fire(text=server.id,
+                          image=location_of_qr,
+                          height_image="450px")
+
     def status(self):
         toast("Calculating...")
         status = Status()
