@@ -4,6 +4,7 @@ from kivymd.uix.gridlayout import MDGridLayout
 from kivymd.uix.screen import MDScreen
 
 from decentra_network.lib.settings_system import d_mode_settings
+from decentra_network.lib.settings_system import mt_settings
 from decentra_network.lib.settings_system import t_mode_settings
 from decentra_network.lib.settings_system import the_settings
 
@@ -14,11 +15,16 @@ class SettingsScreen(MDScreen):
 
 class SettingsBox(MDGridLayout):
     cols = 2
+
     d_first_status = the_settings()["debug_mode"]
     t_first_status = the_settings()["test_mode"]
+    mt_first_status = the_settings()["mute_notifications"]
 
     def D_Status_Changing(self, instance, value):
         d_mode_settings(value)
 
     def T_Status_Changing(self, instance, value):
         t_mode_settings(value)
+
+    def MT_Status_Changing(self, instance, value):
+        mt_settings(value)
