@@ -12,6 +12,7 @@ from kivymd_extensions.sweetalert import SweetAlert
 
 from decentra_network.accounts.get_balance import GetBalance
 from decentra_network.blockchain.block.get_block import GetBlock
+from decentra_network.lib.qr import qr
 from decentra_network.lib.settings_system import change_wallet
 from decentra_network.lib.settings_system import the_settings
 from decentra_network.wallet.ellipticcurve.get_saved_wallet import \
@@ -44,7 +45,7 @@ class WalletBox(MDGridLayout):
 
     def reflesh_balance(self):
 
-        self.text = f"Balance: {str(GetBalance(GetBlock(), wallet_import(-1, 0)))}"
+        self.text = f"Balance: {str(GetBalance(wallet_import(-1, 0)))}"
 
     def show_wallet_alert_dialog(self):
         if not self.wallet_alert_dialog:
@@ -75,11 +76,6 @@ class WalletBox(MDGridLayout):
         if args[0] != the_settings()["wallet"]:
             change_wallet(int(args[0]))
             self.reflesh_balance()
-        Clipboard.copy(wallet_import(int(args[0]), 3))
-        SweetAlert().fire(
-            "The address has been copied to your clipboard.",
-            type="success",
-        )
 
     def show_example_list_bottom_sheet(self):
         bottom_sheet_menu = MDListBottomSheet(radius=25, radius_from="top")
@@ -165,3 +161,17 @@ class WalletBox(MDGridLayout):
                 wallet_delete(each_wallet)
                 self.reflesh_balance()
                 self.dismiss_delete_wallet_alert_dialog(widget)
+
+    def wallet_qr(self):
+        address = wallet_import(-1, 3)
+        location_of_qr = qr(address)
+        SweetAlert().fire(text=address,
+                          image=location_of_qr,
+                          height_image="400px")
+
+    def wallet_copy(self):
+        Clipboard.copy(wallet_import(-1, 3))
+        SweetAlert().fire(
+            "The address has been copied to your clipboard.",
+            type="success",
+        )
