@@ -32,6 +32,7 @@ def create_and_save_the_settings(test_mode_settings=False,
         "debug_mode": debug_mode_settings,
         "wallet": 0,
         "save_blockshash": True,
+        "mute_notifications": False,
     }
 
     save_settings(temp_json)
@@ -64,6 +65,19 @@ def d_mode_settings(new_value):
     save_settings(settings)
 
 
+def mt_settings(new_value):
+    """
+    Changes the mute_notifications setting.
+
+    Inputs:
+      * new_value: New value for the mute_notifications
+    """
+
+    settings = the_settings()
+    settings["mute_notifications"] = new_value
+    save_settings(settings)
+
+
 def change_wallet(new_value):
     """
     Changes the debug_mode setting.
